weaviate.collections.queries package
====================================

.. automodule:: weaviate.collections.queries
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.collections.queries.base module
----------------------------------------

.. automodule:: weaviate.collections.queries.base
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.bm25 module
----------------------------------------

.. automodule:: weaviate.collections.queries.bm25
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.fetch\_objects module
--------------------------------------------------

.. automodule:: weaviate.collections.queries.fetch_objects
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.hybrid module
------------------------------------------

.. automodule:: weaviate.collections.queries.hybrid
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_audio module
-----------------------------------------------

.. automodule:: weaviate.collections.queries.near_audio
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_image module
-----------------------------------------------

.. automodule:: weaviate.collections.queries.near_image
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_object module
------------------------------------------------

.. automodule:: weaviate.collections.queries.near_object
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_text module
----------------------------------------------

.. automodule:: weaviate.collections.queries.near_text
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_vector module
------------------------------------------------

.. automodule:: weaviate.collections.queries.near_vector
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near\_video module
-----------------------------------------------

.. automodule:: weaviate.collections.queries.near_video
   :members:
   :undoc-members:
   :show-inheritance:
